package MT::Plugin::PostToMail;

use strict;
use MT::Mail;
use base qw( MT::Plugin );

my $plugin = new MT::Plugin::PostToMail ({
	name => 'PostToMail',
	version => '1.00',
	doc_link => 'http://blog.webcreativepark.net/2008/05/06-210312.html',
	author_name => 'Kazuma Nishihata',
	author_link => 'http://www.to-r.net',
	description => 'エントリー投稿時に公開状態が未公開のものに関して登録したメールアドレスにメールを送ります。',
	blog_config_template => \&template,
	settings => new MT::PluginSettings([
		['post_mail_address'],
	]),
});

MT->add_plugin ($plugin);

MT->add_callback('CMSPostSave.entry', 9, $plugin, \&post_save_entry);

sub instance { $plugin; }

sub template {
    my $tmpl = <<'TMPL';
<div class="setting">
<div class="label">
<label for="post_mail_address">送信メールアドレス</label>
</div>
<div class="field">
<p><input type="text" name="post_mail_address" id="post_mail_address" value="<TMPL_VAR NAME=POST_MAIL_ADDRESS ESCAPE=HTML>" /></p>
</div>
</div>
TMPL
}


sub post_mail_address {
    my $plugin = shift;
    my ($blog_id) = @_;
    my %param;
    $plugin->load_config(\%param, 'blog:'.$blog_id);
    $param{post_mail_address};
}

sub post_save_entry {
    my ($eh, $app, $obj, $original) = @_;
    require MT::Entry;
    require MT::Author;
    
    if( $obj->status == 1 ){
      my $subject = "エントリーが投稿されました。";
      my $blog_id = $obj->blog_id;
      my $post_mail_address = $plugin->post_mail_address($blog_id);
      my $title = $obj->title;
      my $text = $obj->text;
      my $modified = $obj->modified_on;
      my $author_id = $obj->author_id;
      my $author = MT::Author->load($author_id);
      my $author_name = $author->name;
      my $author_email = $author->email;
      my $from = $author_name."<".$author_email.">";
      my $body = <<EOF;
タイトル：$title
--
$text
--
最終更新日時:$modified
--
更新者:$author_name
--
powerd by PostToMail
http://blog.webcreativepark.net/2008/05/06-210312.html
--
EOF
      my %head = ( To => $post_mail_address , Subject => $subject, FROM => $from);
      MT::Mail->send(\%head, $body);
    }

}
1;